@@ -241,9 +241,13 @@ def hooks(home):
         logging.debug(e, extra={'id': 'MODULE ERROR'})
     finally:
         try:
+            if conf.trace_logging_enabled:
+                logging_module = sys.modules.get("logging")
+                from whatap.trace.mod.logging import instrument_logging
+                instrument_logging(logging_module)
+
             if conf.hook_method_patterns:
                 from whatap.trace.mod.plugin import instrument_plugin
-            
                 patterns = conf.hook_method_patterns.split(',')
                 for pattern in patterns:
                     pattern=pattern.strip()
@@ -370,9 +374,9 @@ def go(batch=False, opts={}):
 import signal
 
 from whatap.trace.mod.application_wsgi import interceptor, start_interceptor, \
-    end_interceptor, trace_handler
-
-from whatap.trace.trace_context import TraceContext
+    end_interceptor, trace_handler, interceptor_step_error
+from whatap.trace.mod.application_fastapi import interceptor_error_log
+from whatap.trace.trace_context import TraceContext, TraceContextManager
 
 def register_app(fn):
     @trace_handler(fn, True)
@@ -399,14 +403,18 @@ def method_profiling(fn):
         try:
             ctx = TraceContext()
             ctx.service_name=fn.__name__
-            ctx = start_interceptor(ctx)
+            start_interceptor(ctx)
             callback = fn(*args, **kwargs)
-            end_interceptor(thread_id= ctx.thread_id)
         except Exception as e:
+            ctx = TraceContextManager.getLocalContext()
+            interceptor_step_error(e, ctx=ctx)
+            interceptor_error_log(ctx.id, e, fn, args, kwargs)
             logging.debug('WHATAP(@method_profiling): ' + str(e),
                           extra={'id': 'WA776'}, exc_info=True)
         finally:
-            return callback if callback else fn(*args, **kwargs)
+            ctx = TraceContextManager.getLocalContext()
+            end_interceptor(ctx=ctx)
+            return callback
     
     if not os.environ.get('whatap.enabled'):
         agent()
