@@ -5,8 +5,8 @@ Configuration = {
     "trace_auto_normalize_enabled": True,
     "trace_user_enabled": True,
     "trace_user_using_ip": True,
-    "trace_logging_enabled": True,
-    "trace_loguru_enabled": True,
+    "trace_logging_enabled": False,
+    "trace_loguru_enabled": False,
     "trace_ignore_url_set": [],
     "trace_ignore_url_prefix": None,
 
